@@ -1,5 +1,7 @@
 """Custom error classes
 """
+from __future__ import annotations
+import loguru
 
 
 class CustomRuntimeError(RuntimeError):
@@ -11,7 +13,7 @@ class ComponentNameError(CustomRuntimeError):
     """Component with given name is in Components
     class instance.
     """
-    def __init__(self, name) -> None:
+    def __init__(self, name: str) -> None:
         self.message = f'Component with {name=} is exist in ' + \
                         'Components class instance or wrong name'
         super().__init__(self.message)
@@ -20,7 +22,7 @@ class ComponentNameError(CustomRuntimeError):
 class ComponentClassError(CustomRuntimeError):
     """Given class isnt component
     """
-    def __init__(self, obj_, logger) -> None:
+    def __init__(self, obj_, logger: loguru.Logger) -> None:
         self.message = f'Given: {obj_} not a component.'
         logger.exception(self.message)
         super().__init__(self.message)
@@ -29,7 +31,7 @@ class ComponentClassError(CustomRuntimeError):
 class StuffDefineError(AttributeError):
     """Defining stuff error
     """
-    def __init__(self, message, logger) -> None:
+    def __init__(self, message: str, logger: loguru.Logger) -> None:
         self.message = message
         logger.exception(self.message)
         super().__init__(self.message)
@@ -38,7 +40,7 @@ class StuffDefineError(AttributeError):
 class ArrangeIndexError(IndexError):
     """Index error for arrange tool
     """
-    def __init__(self, message, logger) -> None:
+    def __init__(self, message: str, logger: loguru.Logger) -> None:
         self.message = message
         logger.exception(self.message)
         super().__init__(self.message)
